from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Devices.Geolocation
import win32more.Windows.Devices.Geolocation.Geofencing
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Win32.System.WinRT
class Geofence(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.Geolocation.Geofencing.IGeofence
    _classid_ = 'Windows.Devices.Geolocation.Geofencing.Geofence'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 2:
            super().__init__(move=win32more.Windows.Devices.Geolocation.Geofencing.Geofence.Create(*args))
        elif len(args) == 4:
            super().__init__(move=win32more.Windows.Devices.Geolocation.Geofencing.Geofence.CreateWithMonitorStates(*args))
        elif len(args) == 5:
            super().__init__(move=win32more.Windows.Devices.Geolocation.Geofencing.Geofence.CreateWithMonitorStatesAndDwellTime(*args))
        elif len(args) == 7:
            super().__init__(move=win32more.Windows.Devices.Geolocation.Geofencing.Geofence.CreateWithMonitorStatesDwellTimeStartTimeAndDuration(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def Create(cls: win32more.Windows.Devices.Geolocation.Geofencing.IGeofenceFactory, id: WinRT_String, geoshape: win32more.Windows.Devices.Geolocation.IGeoshape) -> win32more.Windows.Devices.Geolocation.Geofencing.Geofence: ...
    @winrt_factorymethod
    def CreateWithMonitorStates(cls: win32more.Windows.Devices.Geolocation.Geofencing.IGeofenceFactory, id: WinRT_String, geoshape: win32more.Windows.Devices.Geolocation.IGeoshape, monitoredStates: win32more.Windows.Devices.Geolocation.Geofencing.MonitoredGeofenceStates, singleUse: Boolean) -> win32more.Windows.Devices.Geolocation.Geofencing.Geofence: ...
    @winrt_factorymethod
    def CreateWithMonitorStatesAndDwellTime(cls: win32more.Windows.Devices.Geolocation.Geofencing.IGeofenceFactory, id: WinRT_String, geoshape: win32more.Windows.Devices.Geolocation.IGeoshape, monitoredStates: win32more.Windows.Devices.Geolocation.Geofencing.MonitoredGeofenceStates, singleUse: Boolean, dwellTime: win32more.Windows.Foundation.TimeSpan) -> win32more.Windows.Devices.Geolocation.Geofencing.Geofence: ...
    @winrt_factorymethod
    def CreateWithMonitorStatesDwellTimeStartTimeAndDuration(cls: win32more.Windows.Devices.Geolocation.Geofencing.IGeofenceFactory, id: WinRT_String, geoshape: win32more.Windows.Devices.Geolocation.IGeoshape, monitoredStates: win32more.Windows.Devices.Geolocation.Geofencing.MonitoredGeofenceStates, singleUse: Boolean, dwellTime: win32more.Windows.Foundation.TimeSpan, startTime: win32more.Windows.Foundation.DateTime, duration: win32more.Windows.Foundation.TimeSpan) -> win32more.Windows.Devices.Geolocation.Geofencing.Geofence: ...
    @winrt_mixinmethod
    def get_StartTime(self: win32more.Windows.Devices.Geolocation.Geofencing.IGeofence) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def get_Duration(self: win32more.Windows.Devices.Geolocation.Geofencing.IGeofence) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def get_DwellTime(self: win32more.Windows.Devices.Geolocation.Geofencing.IGeofence) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.Devices.Geolocation.Geofencing.IGeofence) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_MonitoredStates(self: win32more.Windows.Devices.Geolocation.Geofencing.IGeofence) -> win32more.Windows.Devices.Geolocation.Geofencing.MonitoredGeofenceStates: ...
    @winrt_mixinmethod
    def get_Geoshape(self: win32more.Windows.Devices.Geolocation.Geofencing.IGeofence) -> win32more.Windows.Devices.Geolocation.IGeoshape: ...
    @winrt_mixinmethod
    def get_SingleUse(self: win32more.Windows.Devices.Geolocation.Geofencing.IGeofence) -> Boolean: ...
    Duration = property(get_Duration, None)
    DwellTime = property(get_DwellTime, None)
    Geoshape = property(get_Geoshape, None)
    Id = property(get_Id, None)
    MonitoredStates = property(get_MonitoredStates, None)
    SingleUse = property(get_SingleUse, None)
    StartTime = property(get_StartTime, None)
class _GeofenceMonitor_Meta_(ComPtr.__class__):
    pass
class GeofenceMonitor(ComPtr, metaclass=_GeofenceMonitor_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.Geolocation.Geofencing.IGeofenceMonitor
    _classid_ = 'Windows.Devices.Geolocation.Geofencing.GeofenceMonitor'
    @winrt_mixinmethod
    def get_Status(self: win32more.Windows.Devices.Geolocation.Geofencing.IGeofenceMonitor) -> win32more.Windows.Devices.Geolocation.Geofencing.GeofenceMonitorStatus: ...
    @winrt_mixinmethod
    def get_Geofences(self: win32more.Windows.Devices.Geolocation.Geofencing.IGeofenceMonitor) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Devices.Geolocation.Geofencing.Geofence]: ...
    @winrt_mixinmethod
    def get_LastKnownGeoposition(self: win32more.Windows.Devices.Geolocation.Geofencing.IGeofenceMonitor) -> win32more.Windows.Devices.Geolocation.Geoposition: ...
    @winrt_mixinmethod
    def add_GeofenceStateChanged(self: win32more.Windows.Devices.Geolocation.Geofencing.IGeofenceMonitor, eventHandler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Devices.Geolocation.Geofencing.GeofenceMonitor, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_GeofenceStateChanged(self: win32more.Windows.Devices.Geolocation.Geofencing.IGeofenceMonitor, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def ReadReports(self: win32more.Windows.Devices.Geolocation.Geofencing.IGeofenceMonitor) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.Geolocation.Geofencing.GeofenceStateChangeReport]: ...
    @winrt_mixinmethod
    def add_StatusChanged(self: win32more.Windows.Devices.Geolocation.Geofencing.IGeofenceMonitor, eventHandler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Devices.Geolocation.Geofencing.GeofenceMonitor, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_StatusChanged(self: win32more.Windows.Devices.Geolocation.Geofencing.IGeofenceMonitor, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_Current(cls: win32more.Windows.Devices.Geolocation.Geofencing.IGeofenceMonitorStatics) -> win32more.Windows.Devices.Geolocation.Geofencing.GeofenceMonitor: ...
    Geofences = property(get_Geofences, None)
    LastKnownGeoposition = property(get_LastKnownGeoposition, None)
    Status = property(get_Status, None)
    _GeofenceMonitor_Meta_.Current = property(get_Current, None)
    GeofenceStateChanged = event()
    StatusChanged = event()
class GeofenceMonitorStatus(Enum, Int32):
    Ready = 0
    Initializing = 1
    NoData = 2
    Disabled = 3
    NotInitialized = 4
    NotAvailable = 5
class GeofenceRemovalReason(Enum, Int32):
    Used = 0
    Expired = 1
class GeofenceState(Enum, UInt32):
    None_ = 0
    Entered = 1
    Exited = 2
    Removed = 4
class GeofenceStateChangeReport(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.Geolocation.Geofencing.IGeofenceStateChangeReport
    _classid_ = 'Windows.Devices.Geolocation.Geofencing.GeofenceStateChangeReport'
    @winrt_mixinmethod
    def get_NewState(self: win32more.Windows.Devices.Geolocation.Geofencing.IGeofenceStateChangeReport) -> win32more.Windows.Devices.Geolocation.Geofencing.GeofenceState: ...
    @winrt_mixinmethod
    def get_Geofence(self: win32more.Windows.Devices.Geolocation.Geofencing.IGeofenceStateChangeReport) -> win32more.Windows.Devices.Geolocation.Geofencing.Geofence: ...
    @winrt_mixinmethod
    def get_Geoposition(self: win32more.Windows.Devices.Geolocation.Geofencing.IGeofenceStateChangeReport) -> win32more.Windows.Devices.Geolocation.Geoposition: ...
    @winrt_mixinmethod
    def get_RemovalReason(self: win32more.Windows.Devices.Geolocation.Geofencing.IGeofenceStateChangeReport) -> win32more.Windows.Devices.Geolocation.Geofencing.GeofenceRemovalReason: ...
    Geofence = property(get_Geofence, None)
    Geoposition = property(get_Geoposition, None)
    NewState = property(get_NewState, None)
    RemovalReason = property(get_RemovalReason, None)
class IGeofence(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Geolocation.Geofencing.IGeofence'
    _iid_ = Guid('{9c090823-edb8-47e0-8245-5bf61d321f2d}')
    @winrt_commethod(6)
    def get_StartTime(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(7)
    def get_Duration(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(8)
    def get_DwellTime(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(9)
    def get_Id(self) -> WinRT_String: ...
    @winrt_commethod(10)
    def get_MonitoredStates(self) -> win32more.Windows.Devices.Geolocation.Geofencing.MonitoredGeofenceStates: ...
    @winrt_commethod(11)
    def get_Geoshape(self) -> win32more.Windows.Devices.Geolocation.IGeoshape: ...
    @winrt_commethod(12)
    def get_SingleUse(self) -> Boolean: ...
    Duration = property(get_Duration, None)
    DwellTime = property(get_DwellTime, None)
    Geoshape = property(get_Geoshape, None)
    Id = property(get_Id, None)
    MonitoredStates = property(get_MonitoredStates, None)
    SingleUse = property(get_SingleUse, None)
    StartTime = property(get_StartTime, None)
class IGeofenceFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Geolocation.Geofencing.IGeofenceFactory'
    _iid_ = Guid('{841f624b-325f-4b90-bca7-2b8022a93796}')
    @winrt_commethod(6)
    def Create(self, id: WinRT_String, geoshape: win32more.Windows.Devices.Geolocation.IGeoshape) -> win32more.Windows.Devices.Geolocation.Geofencing.Geofence: ...
    @winrt_commethod(7)
    def CreateWithMonitorStates(self, id: WinRT_String, geoshape: win32more.Windows.Devices.Geolocation.IGeoshape, monitoredStates: win32more.Windows.Devices.Geolocation.Geofencing.MonitoredGeofenceStates, singleUse: Boolean) -> win32more.Windows.Devices.Geolocation.Geofencing.Geofence: ...
    @winrt_commethod(8)
    def CreateWithMonitorStatesAndDwellTime(self, id: WinRT_String, geoshape: win32more.Windows.Devices.Geolocation.IGeoshape, monitoredStates: win32more.Windows.Devices.Geolocation.Geofencing.MonitoredGeofenceStates, singleUse: Boolean, dwellTime: win32more.Windows.Foundation.TimeSpan) -> win32more.Windows.Devices.Geolocation.Geofencing.Geofence: ...
    @winrt_commethod(9)
    def CreateWithMonitorStatesDwellTimeStartTimeAndDuration(self, id: WinRT_String, geoshape: win32more.Windows.Devices.Geolocation.IGeoshape, monitoredStates: win32more.Windows.Devices.Geolocation.Geofencing.MonitoredGeofenceStates, singleUse: Boolean, dwellTime: win32more.Windows.Foundation.TimeSpan, startTime: win32more.Windows.Foundation.DateTime, duration: win32more.Windows.Foundation.TimeSpan) -> win32more.Windows.Devices.Geolocation.Geofencing.Geofence: ...
class IGeofenceMonitor(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Geolocation.Geofencing.IGeofenceMonitor'
    _iid_ = Guid('{4c0f5f78-1c1f-4621-bbbd-833b92247226}')
    @winrt_commethod(6)
    def get_Status(self) -> win32more.Windows.Devices.Geolocation.Geofencing.GeofenceMonitorStatus: ...
    @winrt_commethod(7)
    def get_Geofences(self) -> win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Devices.Geolocation.Geofencing.Geofence]: ...
    @winrt_commethod(8)
    def get_LastKnownGeoposition(self) -> win32more.Windows.Devices.Geolocation.Geoposition: ...
    @winrt_commethod(9)
    def add_GeofenceStateChanged(self, eventHandler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Devices.Geolocation.Geofencing.GeofenceMonitor, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(10)
    def remove_GeofenceStateChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(11)
    def ReadReports(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.Geolocation.Geofencing.GeofenceStateChangeReport]: ...
    @winrt_commethod(12)
    def add_StatusChanged(self, eventHandler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Devices.Geolocation.Geofencing.GeofenceMonitor, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_StatusChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Geofences = property(get_Geofences, None)
    LastKnownGeoposition = property(get_LastKnownGeoposition, None)
    Status = property(get_Status, None)
    GeofenceStateChanged = event()
    StatusChanged = event()
class IGeofenceMonitorStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Geolocation.Geofencing.IGeofenceMonitorStatics'
    _iid_ = Guid('{2dd32fcf-7e75-4899-ace3-2bd0a65cce06}')
    @winrt_commethod(6)
    def get_Current(self) -> win32more.Windows.Devices.Geolocation.Geofencing.GeofenceMonitor: ...
    Current = property(get_Current, None)
class IGeofenceStateChangeReport(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Geolocation.Geofencing.IGeofenceStateChangeReport'
    _iid_ = Guid('{9a243c18-2464-4c89-be05-b3ffff5babc5}')
    @winrt_commethod(6)
    def get_NewState(self) -> win32more.Windows.Devices.Geolocation.Geofencing.GeofenceState: ...
    @winrt_commethod(7)
    def get_Geofence(self) -> win32more.Windows.Devices.Geolocation.Geofencing.Geofence: ...
    @winrt_commethod(8)
    def get_Geoposition(self) -> win32more.Windows.Devices.Geolocation.Geoposition: ...
    @winrt_commethod(9)
    def get_RemovalReason(self) -> win32more.Windows.Devices.Geolocation.Geofencing.GeofenceRemovalReason: ...
    Geofence = property(get_Geofence, None)
    Geoposition = property(get_Geoposition, None)
    NewState = property(get_NewState, None)
    RemovalReason = property(get_RemovalReason, None)
class MonitoredGeofenceStates(Enum, UInt32):
    None_ = 0
    Entered = 1
    Exited = 2
    Removed = 4


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.ApplicationModel.Preview.Notes
import win32more.Windows.Foundation
import win32more.Windows.Graphics.Imaging
import win32more.Windows.Storage.Streams
import win32more.Windows.Win32.System.WinRT
class INotePlacementChangedPreviewEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Preview.Notes.INotePlacementChangedPreviewEventArgs'
    _iid_ = Guid('{491d57b7-f780-4e7f-a939-9a4caf965214}')
    @winrt_commethod(6)
    def get_ViewId(self) -> Int32: ...
    ViewId = property(get_ViewId, None)
class INoteVisibilityChangedPreviewEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Preview.Notes.INoteVisibilityChangedPreviewEventArgs'
    _iid_ = Guid('{0e34649e-3815-4ff6-83b3-a14d17120e24}')
    @winrt_commethod(6)
    def get_ViewId(self) -> Int32: ...
    @winrt_commethod(7)
    def get_IsVisible(self) -> Boolean: ...
    IsVisible = property(get_IsVisible, None)
    ViewId = property(get_ViewId, None)
class INotesWindowManagerPreview(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Preview.Notes.INotesWindowManagerPreview'
    _iid_ = Guid('{dc2ac23e-4850-4f13-9cc7-ff487efdfcde}')
    @winrt_commethod(6)
    def get_IsScreenLocked(self) -> Boolean: ...
    @winrt_commethod(7)
    def ShowNote(self, noteViewId: Int32) -> Void: ...
    @winrt_commethod(8)
    def ShowNoteRelativeTo(self, noteViewId: Int32, anchorNoteViewId: Int32) -> Void: ...
    @winrt_commethod(9)
    def ShowNoteWithPlacement(self, noteViewId: Int32, data: win32more.Windows.Storage.Streams.IBuffer) -> Void: ...
    @winrt_commethod(10)
    def HideNote(self, noteViewId: Int32) -> Void: ...
    @winrt_commethod(11)
    def GetNotePlacement(self, noteViewId: Int32) -> win32more.Windows.Storage.Streams.IBuffer: ...
    @winrt_commethod(12)
    def TrySetNoteSize(self, noteViewId: Int32, size: win32more.Windows.Foundation.Size) -> Boolean: ...
    @winrt_commethod(13)
    def SetFocusToNextView(self) -> Void: ...
    @winrt_commethod(14)
    def SetNotesThumbnailAsync(self, thumbnail: win32more.Windows.Storage.Streams.IBuffer) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(15)
    def add_SystemLockStateChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Preview.Notes.NotesWindowManagerPreview, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(16)
    def remove_SystemLockStateChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(17)
    def add_NotePlacementChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Preview.Notes.NotesWindowManagerPreview, win32more.Windows.ApplicationModel.Preview.Notes.NotePlacementChangedPreviewEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(18)
    def remove_NotePlacementChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(19)
    def add_NoteVisibilityChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Preview.Notes.NotesWindowManagerPreview, win32more.Windows.ApplicationModel.Preview.Notes.NoteVisibilityChangedPreviewEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(20)
    def remove_NoteVisibilityChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    IsScreenLocked = property(get_IsScreenLocked, None)
    SystemLockStateChanged = event()
    NotePlacementChanged = event()
    NoteVisibilityChanged = event()
class INotesWindowManagerPreview2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Preview.Notes.INotesWindowManagerPreview2'
    _iid_ = Guid('{edfe864a-1f54-4b09-9823-ff477f6fa3bc}')
    @winrt_commethod(6)
    def ShowNoteRelativeToWithOptions(self, noteViewId: Int32, anchorNoteViewId: Int32, options: win32more.Windows.ApplicationModel.Preview.Notes.NotesWindowManagerPreviewShowNoteOptions) -> Void: ...
    @winrt_commethod(7)
    def ShowNoteWithPlacementWithOptions(self, noteViewId: Int32, data: win32more.Windows.Storage.Streams.IBuffer, options: win32more.Windows.ApplicationModel.Preview.Notes.NotesWindowManagerPreviewShowNoteOptions) -> Void: ...
    @winrt_commethod(8)
    def SetFocusToPreviousView(self) -> Void: ...
    @winrt_commethod(9)
    def SetThumbnailImageForTaskSwitcherAsync(self, bitmap: win32more.Windows.Graphics.Imaging.SoftwareBitmap) -> win32more.Windows.Foundation.IAsyncAction: ...
class INotesWindowManagerPreviewShowNoteOptions(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Preview.Notes.INotesWindowManagerPreviewShowNoteOptions'
    _iid_ = Guid('{886b09d6-a6ae-4007-a56d-1ca70c84c0d2}')
    @winrt_commethod(6)
    def get_ShowWithFocus(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_ShowWithFocus(self, value: Boolean) -> Void: ...
    ShowWithFocus = property(get_ShowWithFocus, put_ShowWithFocus)
class INotesWindowManagerPreviewStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Preview.Notes.INotesWindowManagerPreviewStatics'
    _iid_ = Guid('{6668cc88-0a8e-4127-a38e-995445868a78}')
    @winrt_commethod(6)
    def GetForCurrentApp(self) -> win32more.Windows.ApplicationModel.Preview.Notes.NotesWindowManagerPreview: ...
class NotePlacementChangedPreviewEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Preview.Notes.INotePlacementChangedPreviewEventArgs
    _classid_ = 'Windows.ApplicationModel.Preview.Notes.NotePlacementChangedPreviewEventArgs'
    @winrt_mixinmethod
    def get_ViewId(self: win32more.Windows.ApplicationModel.Preview.Notes.INotePlacementChangedPreviewEventArgs) -> Int32: ...
    ViewId = property(get_ViewId, None)
class NoteVisibilityChangedPreviewEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Preview.Notes.INoteVisibilityChangedPreviewEventArgs
    _classid_ = 'Windows.ApplicationModel.Preview.Notes.NoteVisibilityChangedPreviewEventArgs'
    @winrt_mixinmethod
    def get_ViewId(self: win32more.Windows.ApplicationModel.Preview.Notes.INoteVisibilityChangedPreviewEventArgs) -> Int32: ...
    @winrt_mixinmethod
    def get_IsVisible(self: win32more.Windows.ApplicationModel.Preview.Notes.INoteVisibilityChangedPreviewEventArgs) -> Boolean: ...
    IsVisible = property(get_IsVisible, None)
    ViewId = property(get_ViewId, None)
class NotesWindowManagerPreview(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Preview.Notes.INotesWindowManagerPreview
    _classid_ = 'Windows.ApplicationModel.Preview.Notes.NotesWindowManagerPreview'
    @winrt_mixinmethod
    def get_IsScreenLocked(self: win32more.Windows.ApplicationModel.Preview.Notes.INotesWindowManagerPreview) -> Boolean: ...
    @winrt_mixinmethod
    def ShowNote(self: win32more.Windows.ApplicationModel.Preview.Notes.INotesWindowManagerPreview, noteViewId: Int32) -> Void: ...
    @winrt_mixinmethod
    def ShowNoteRelativeTo(self: win32more.Windows.ApplicationModel.Preview.Notes.INotesWindowManagerPreview, noteViewId: Int32, anchorNoteViewId: Int32) -> Void: ...
    @winrt_mixinmethod
    def ShowNoteWithPlacement(self: win32more.Windows.ApplicationModel.Preview.Notes.INotesWindowManagerPreview, noteViewId: Int32, data: win32more.Windows.Storage.Streams.IBuffer) -> Void: ...
    @winrt_mixinmethod
    def HideNote(self: win32more.Windows.ApplicationModel.Preview.Notes.INotesWindowManagerPreview, noteViewId: Int32) -> Void: ...
    @winrt_mixinmethod
    def GetNotePlacement(self: win32more.Windows.ApplicationModel.Preview.Notes.INotesWindowManagerPreview, noteViewId: Int32) -> win32more.Windows.Storage.Streams.IBuffer: ...
    @winrt_mixinmethod
    def TrySetNoteSize(self: win32more.Windows.ApplicationModel.Preview.Notes.INotesWindowManagerPreview, noteViewId: Int32, size: win32more.Windows.Foundation.Size) -> Boolean: ...
    @winrt_mixinmethod
    def SetFocusToNextView(self: win32more.Windows.ApplicationModel.Preview.Notes.INotesWindowManagerPreview) -> Void: ...
    @winrt_mixinmethod
    def SetNotesThumbnailAsync(self: win32more.Windows.ApplicationModel.Preview.Notes.INotesWindowManagerPreview, thumbnail: win32more.Windows.Storage.Streams.IBuffer) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def add_SystemLockStateChanged(self: win32more.Windows.ApplicationModel.Preview.Notes.INotesWindowManagerPreview, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Preview.Notes.NotesWindowManagerPreview, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SystemLockStateChanged(self: win32more.Windows.ApplicationModel.Preview.Notes.INotesWindowManagerPreview, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_NotePlacementChanged(self: win32more.Windows.ApplicationModel.Preview.Notes.INotesWindowManagerPreview, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Preview.Notes.NotesWindowManagerPreview, win32more.Windows.ApplicationModel.Preview.Notes.NotePlacementChangedPreviewEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_NotePlacementChanged(self: win32more.Windows.ApplicationModel.Preview.Notes.INotesWindowManagerPreview, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_NoteVisibilityChanged(self: win32more.Windows.ApplicationModel.Preview.Notes.INotesWindowManagerPreview, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Preview.Notes.NotesWindowManagerPreview, win32more.Windows.ApplicationModel.Preview.Notes.NoteVisibilityChangedPreviewEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_NoteVisibilityChanged(self: win32more.Windows.ApplicationModel.Preview.Notes.INotesWindowManagerPreview, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def ShowNoteRelativeToWithOptions(self: win32more.Windows.ApplicationModel.Preview.Notes.INotesWindowManagerPreview2, noteViewId: Int32, anchorNoteViewId: Int32, options: win32more.Windows.ApplicationModel.Preview.Notes.NotesWindowManagerPreviewShowNoteOptions) -> Void: ...
    @winrt_mixinmethod
    def ShowNoteWithPlacementWithOptions(self: win32more.Windows.ApplicationModel.Preview.Notes.INotesWindowManagerPreview2, noteViewId: Int32, data: win32more.Windows.Storage.Streams.IBuffer, options: win32more.Windows.ApplicationModel.Preview.Notes.NotesWindowManagerPreviewShowNoteOptions) -> Void: ...
    @winrt_mixinmethod
    def SetFocusToPreviousView(self: win32more.Windows.ApplicationModel.Preview.Notes.INotesWindowManagerPreview2) -> Void: ...
    @winrt_mixinmethod
    def SetThumbnailImageForTaskSwitcherAsync(self: win32more.Windows.ApplicationModel.Preview.Notes.INotesWindowManagerPreview2, bitmap: win32more.Windows.Graphics.Imaging.SoftwareBitmap) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_classmethod
    def GetForCurrentApp(cls: win32more.Windows.ApplicationModel.Preview.Notes.INotesWindowManagerPreviewStatics) -> win32more.Windows.ApplicationModel.Preview.Notes.NotesWindowManagerPreview: ...
    IsScreenLocked = property(get_IsScreenLocked, None)
    SystemLockStateChanged = event()
    NotePlacementChanged = event()
    NoteVisibilityChanged = event()
class NotesWindowManagerPreviewShowNoteOptions(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Preview.Notes.INotesWindowManagerPreviewShowNoteOptions
    _classid_ = 'Windows.ApplicationModel.Preview.Notes.NotesWindowManagerPreviewShowNoteOptions'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.ApplicationModel.Preview.Notes.NotesWindowManagerPreviewShowNoteOptions.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.ApplicationModel.Preview.Notes.NotesWindowManagerPreviewShowNoteOptions: ...
    @winrt_mixinmethod
    def get_ShowWithFocus(self: win32more.Windows.ApplicationModel.Preview.Notes.INotesWindowManagerPreviewShowNoteOptions) -> Boolean: ...
    @winrt_mixinmethod
    def put_ShowWithFocus(self: win32more.Windows.ApplicationModel.Preview.Notes.INotesWindowManagerPreviewShowNoteOptions, value: Boolean) -> Void: ...
    ShowWithFocus = property(get_ShowWithFocus, put_ShowWithFocus)
PreviewNotesContract: UInt32 = 131072


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Gaming.XboxLive.Storage
import win32more.Windows.Storage.Streams
import win32more.Windows.System
import win32more.Windows.Win32.System.WinRT
class GameSaveBlobGetResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveBlobGetResult
    _classid_ = 'Windows.Gaming.XboxLive.Storage.GameSaveBlobGetResult'
    @winrt_mixinmethod
    def get_Status(self: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveBlobGetResult) -> win32more.Windows.Gaming.XboxLive.Storage.GameSaveErrorStatus: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveBlobGetResult) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Storage.Streams.IBuffer]: ...
    Status = property(get_Status, None)
    Value = property(get_Value, None)
class GameSaveBlobInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveBlobInfo
    _classid_ = 'Windows.Gaming.XboxLive.Storage.GameSaveBlobInfo'
    @winrt_mixinmethod
    def get_Name(self: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveBlobInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveBlobInfo) -> UInt32: ...
    Name = property(get_Name, None)
    Size = property(get_Size, None)
class GameSaveBlobInfoGetResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveBlobInfoGetResult
    _classid_ = 'Windows.Gaming.XboxLive.Storage.GameSaveBlobInfoGetResult'
    @winrt_mixinmethod
    def get_Status(self: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveBlobInfoGetResult) -> win32more.Windows.Gaming.XboxLive.Storage.GameSaveErrorStatus: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveBlobInfoGetResult) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Gaming.XboxLive.Storage.GameSaveBlobInfo]: ...
    Status = property(get_Status, None)
    Value = property(get_Value, None)
class GameSaveBlobInfoQuery(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveBlobInfoQuery
    _classid_ = 'Windows.Gaming.XboxLive.Storage.GameSaveBlobInfoQuery'
    @winrt_mixinmethod
    def GetBlobInfoAsync(self: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveBlobInfoQuery) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Gaming.XboxLive.Storage.GameSaveBlobInfoGetResult]: ...
    @winrt_mixinmethod
    def GetBlobInfoWithIndexAndMaxAsync(self: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveBlobInfoQuery, startIndex: UInt32, maxNumberOfItems: UInt32) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Gaming.XboxLive.Storage.GameSaveBlobInfoGetResult]: ...
    @winrt_mixinmethod
    def GetItemCountAsync(self: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveBlobInfoQuery) -> win32more.Windows.Foundation.IAsyncOperation[UInt32]: ...
class GameSaveContainer(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveContainer
    _classid_ = 'Windows.Gaming.XboxLive.Storage.GameSaveContainer'
    @winrt_mixinmethod
    def get_Name(self: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveContainer) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Provider(self: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveContainer) -> win32more.Windows.Gaming.XboxLive.Storage.GameSaveProvider: ...
    @winrt_mixinmethod
    def SubmitUpdatesAsync(self: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveContainer, blobsToWrite: win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Storage.Streams.IBuffer], blobsToDelete: win32more.Windows.Foundation.Collections.IIterable[WinRT_String], displayName: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Gaming.XboxLive.Storage.GameSaveOperationResult]: ...
    @winrt_mixinmethod
    def ReadAsync(self: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveContainer, blobsToRead: win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Storage.Streams.IBuffer]) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Gaming.XboxLive.Storage.GameSaveOperationResult]: ...
    @winrt_mixinmethod
    def GetAsync(self: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveContainer, blobsToRead: win32more.Windows.Foundation.Collections.IIterable[WinRT_String]) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Gaming.XboxLive.Storage.GameSaveBlobGetResult]: ...
    @winrt_mixinmethod
    def SubmitPropertySetUpdatesAsync(self: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveContainer, blobsToWrite: win32more.Windows.Foundation.Collections.IPropertySet, blobsToDelete: win32more.Windows.Foundation.Collections.IIterable[WinRT_String], displayName: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Gaming.XboxLive.Storage.GameSaveOperationResult]: ...
    @winrt_mixinmethod
    def CreateBlobInfoQuery(self: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveContainer, blobNamePrefix: WinRT_String) -> win32more.Windows.Gaming.XboxLive.Storage.GameSaveBlobInfoQuery: ...
    Name = property(get_Name, None)
    Provider = property(get_Provider, None)
class GameSaveContainerInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveContainerInfo
    _classid_ = 'Windows.Gaming.XboxLive.Storage.GameSaveContainerInfo'
    @winrt_mixinmethod
    def get_Name(self: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveContainerInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_TotalSize(self: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveContainerInfo) -> UInt64: ...
    @winrt_mixinmethod
    def get_DisplayName(self: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveContainerInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_LastModifiedTime(self: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveContainerInfo) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def get_NeedsSync(self: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveContainerInfo) -> Boolean: ...
    DisplayName = property(get_DisplayName, None)
    LastModifiedTime = property(get_LastModifiedTime, None)
    Name = property(get_Name, None)
    NeedsSync = property(get_NeedsSync, None)
    TotalSize = property(get_TotalSize, None)
class GameSaveContainerInfoGetResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveContainerInfoGetResult
    _classid_ = 'Windows.Gaming.XboxLive.Storage.GameSaveContainerInfoGetResult'
    @winrt_mixinmethod
    def get_Status(self: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveContainerInfoGetResult) -> win32more.Windows.Gaming.XboxLive.Storage.GameSaveErrorStatus: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveContainerInfoGetResult) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Gaming.XboxLive.Storage.GameSaveContainerInfo]: ...
    Status = property(get_Status, None)
    Value = property(get_Value, None)
class GameSaveContainerInfoQuery(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveContainerInfoQuery
    _classid_ = 'Windows.Gaming.XboxLive.Storage.GameSaveContainerInfoQuery'
    @winrt_mixinmethod
    def GetContainerInfoAsync(self: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveContainerInfoQuery) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Gaming.XboxLive.Storage.GameSaveContainerInfoGetResult]: ...
    @winrt_mixinmethod
    def GetContainerInfoWithIndexAndMaxAsync(self: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveContainerInfoQuery, startIndex: UInt32, maxNumberOfItems: UInt32) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Gaming.XboxLive.Storage.GameSaveContainerInfoGetResult]: ...
    @winrt_mixinmethod
    def GetItemCountAsync(self: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveContainerInfoQuery) -> win32more.Windows.Foundation.IAsyncOperation[UInt32]: ...
class GameSaveErrorStatus(Enum, Int32):
    Ok = 0
    Abort = -2147467260
    InvalidContainerName = -2138898431
    NoAccess = -2138898430
    OutOfLocalStorage = -2138898429
    UserCanceled = -2138898428
    UpdateTooBig = -2138898427
    QuotaExceeded = -2138898426
    ProvidedBufferTooSmall = -2138898425
    BlobNotFound = -2138898424
    NoXboxLiveInfo = -2138898423
    ContainerNotInSync = -2138898422
    ContainerSyncFailed = -2138898421
    UserHasNoXboxLiveInfo = -2138898420
    ObjectExpired = -2138898419
class GameSaveOperationResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveOperationResult
    _classid_ = 'Windows.Gaming.XboxLive.Storage.GameSaveOperationResult'
    @winrt_mixinmethod
    def get_Status(self: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveOperationResult) -> win32more.Windows.Gaming.XboxLive.Storage.GameSaveErrorStatus: ...
    Status = property(get_Status, None)
class GameSaveProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveProvider
    _classid_ = 'Windows.Gaming.XboxLive.Storage.GameSaveProvider'
    @winrt_mixinmethod
    def get_User(self: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveProvider) -> win32more.Windows.System.User: ...
    @winrt_mixinmethod
    def CreateContainer(self: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveProvider, name: WinRT_String) -> win32more.Windows.Gaming.XboxLive.Storage.GameSaveContainer: ...
    @winrt_mixinmethod
    def DeleteContainerAsync(self: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveProvider, name: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Gaming.XboxLive.Storage.GameSaveOperationResult]: ...
    @winrt_mixinmethod
    def CreateContainerInfoQuery(self: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveProvider) -> win32more.Windows.Gaming.XboxLive.Storage.GameSaveContainerInfoQuery: ...
    @winrt_mixinmethod
    def CreateContainerInfoQueryWithName(self: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveProvider, containerNamePrefix: WinRT_String) -> win32more.Windows.Gaming.XboxLive.Storage.GameSaveContainerInfoQuery: ...
    @winrt_mixinmethod
    def GetRemainingBytesInQuotaAsync(self: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveProvider) -> win32more.Windows.Foundation.IAsyncOperation[Int64]: ...
    @winrt_mixinmethod
    def get_ContainersChangedSinceLastSync(self: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveProvider) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_classmethod
    def GetForUserAsync(cls: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveProviderStatics, user: win32more.Windows.System.User, serviceConfigId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Gaming.XboxLive.Storage.GameSaveProviderGetResult]: ...
    @winrt_classmethod
    def GetSyncOnDemandForUserAsync(cls: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveProviderStatics, user: win32more.Windows.System.User, serviceConfigId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Gaming.XboxLive.Storage.GameSaveProviderGetResult]: ...
    ContainersChangedSinceLastSync = property(get_ContainersChangedSinceLastSync, None)
    User = property(get_User, None)
class GameSaveProviderGetResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveProviderGetResult
    _classid_ = 'Windows.Gaming.XboxLive.Storage.GameSaveProviderGetResult'
    @winrt_mixinmethod
    def get_Status(self: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveProviderGetResult) -> win32more.Windows.Gaming.XboxLive.Storage.GameSaveErrorStatus: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Gaming.XboxLive.Storage.IGameSaveProviderGetResult) -> win32more.Windows.Gaming.XboxLive.Storage.GameSaveProvider: ...
    Status = property(get_Status, None)
    Value = property(get_Value, None)
class IGameSaveBlobGetResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.XboxLive.Storage.IGameSaveBlobGetResult'
    _iid_ = Guid('{917281e0-7201-4953-aa2c-4008f03aef45}')
    @winrt_commethod(6)
    def get_Status(self) -> win32more.Windows.Gaming.XboxLive.Storage.GameSaveErrorStatus: ...
    @winrt_commethod(7)
    def get_Value(self) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Storage.Streams.IBuffer]: ...
    Status = property(get_Status, None)
    Value = property(get_Value, None)
class IGameSaveBlobInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.XboxLive.Storage.IGameSaveBlobInfo'
    _iid_ = Guid('{add38034-baf0-4645-b6d0-46edaffb3c2b}')
    @winrt_commethod(6)
    def get_Name(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Size(self) -> UInt32: ...
    Name = property(get_Name, None)
    Size = property(get_Size, None)
class IGameSaveBlobInfoGetResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.XboxLive.Storage.IGameSaveBlobInfoGetResult'
    _iid_ = Guid('{c7578582-3697-42bf-989c-665d923b5231}')
    @winrt_commethod(6)
    def get_Status(self) -> win32more.Windows.Gaming.XboxLive.Storage.GameSaveErrorStatus: ...
    @winrt_commethod(7)
    def get_Value(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Gaming.XboxLive.Storage.GameSaveBlobInfo]: ...
    Status = property(get_Status, None)
    Value = property(get_Value, None)
class IGameSaveBlobInfoQuery(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.XboxLive.Storage.IGameSaveBlobInfoQuery'
    _iid_ = Guid('{9fdd74b2-eeee-447b-a9d2-7f96c0f83208}')
    @winrt_commethod(6)
    def GetBlobInfoAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Gaming.XboxLive.Storage.GameSaveBlobInfoGetResult]: ...
    @winrt_commethod(7)
    def GetBlobInfoWithIndexAndMaxAsync(self, startIndex: UInt32, maxNumberOfItems: UInt32) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Gaming.XboxLive.Storage.GameSaveBlobInfoGetResult]: ...
    @winrt_commethod(8)
    def GetItemCountAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[UInt32]: ...
class IGameSaveContainer(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.XboxLive.Storage.IGameSaveContainer'
    _iid_ = Guid('{c3c08f89-563f-4ecd-9c6f-33fd0e323d10}')
    @winrt_commethod(6)
    def get_Name(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Provider(self) -> win32more.Windows.Gaming.XboxLive.Storage.GameSaveProvider: ...
    @winrt_commethod(8)
    def SubmitUpdatesAsync(self, blobsToWrite: win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Storage.Streams.IBuffer], blobsToDelete: win32more.Windows.Foundation.Collections.IIterable[WinRT_String], displayName: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Gaming.XboxLive.Storage.GameSaveOperationResult]: ...
    @winrt_commethod(9)
    def ReadAsync(self, blobsToRead: win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Storage.Streams.IBuffer]) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Gaming.XboxLive.Storage.GameSaveOperationResult]: ...
    @winrt_commethod(10)
    def GetAsync(self, blobsToRead: win32more.Windows.Foundation.Collections.IIterable[WinRT_String]) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Gaming.XboxLive.Storage.GameSaveBlobGetResult]: ...
    @winrt_commethod(11)
    def SubmitPropertySetUpdatesAsync(self, blobsToWrite: win32more.Windows.Foundation.Collections.IPropertySet, blobsToDelete: win32more.Windows.Foundation.Collections.IIterable[WinRT_String], displayName: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Gaming.XboxLive.Storage.GameSaveOperationResult]: ...
    @winrt_commethod(12)
    def CreateBlobInfoQuery(self, blobNamePrefix: WinRT_String) -> win32more.Windows.Gaming.XboxLive.Storage.GameSaveBlobInfoQuery: ...
    Name = property(get_Name, None)
    Provider = property(get_Provider, None)
class IGameSaveContainerInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.XboxLive.Storage.IGameSaveContainerInfo'
    _iid_ = Guid('{b7e27300-155d-4bb4-b2ba-930306f391b5}')
    @winrt_commethod(6)
    def get_Name(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_TotalSize(self) -> UInt64: ...
    @winrt_commethod(8)
    def get_DisplayName(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def get_LastModifiedTime(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(10)
    def get_NeedsSync(self) -> Boolean: ...
    DisplayName = property(get_DisplayName, None)
    LastModifiedTime = property(get_LastModifiedTime, None)
    Name = property(get_Name, None)
    NeedsSync = property(get_NeedsSync, None)
    TotalSize = property(get_TotalSize, None)
class IGameSaveContainerInfoGetResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.XboxLive.Storage.IGameSaveContainerInfoGetResult'
    _iid_ = Guid('{ffc50d74-c581-4f9d-9e39-30a10c1e4c50}')
    @winrt_commethod(6)
    def get_Status(self) -> win32more.Windows.Gaming.XboxLive.Storage.GameSaveErrorStatus: ...
    @winrt_commethod(7)
    def get_Value(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Gaming.XboxLive.Storage.GameSaveContainerInfo]: ...
    Status = property(get_Status, None)
    Value = property(get_Value, None)
class IGameSaveContainerInfoQuery(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.XboxLive.Storage.IGameSaveContainerInfoQuery'
    _iid_ = Guid('{3c94e863-6f80-4327-9327-ffc11afd42b3}')
    @winrt_commethod(6)
    def GetContainerInfoAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Gaming.XboxLive.Storage.GameSaveContainerInfoGetResult]: ...
    @winrt_commethod(7)
    def GetContainerInfoWithIndexAndMaxAsync(self, startIndex: UInt32, maxNumberOfItems: UInt32) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Gaming.XboxLive.Storage.GameSaveContainerInfoGetResult]: ...
    @winrt_commethod(8)
    def GetItemCountAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[UInt32]: ...
class IGameSaveOperationResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.XboxLive.Storage.IGameSaveOperationResult'
    _iid_ = Guid('{cf0f1a05-24a0-4582-9a55-b1bbbb9388d8}')
    @winrt_commethod(6)
    def get_Status(self) -> win32more.Windows.Gaming.XboxLive.Storage.GameSaveErrorStatus: ...
    Status = property(get_Status, None)
class IGameSaveProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.XboxLive.Storage.IGameSaveProvider'
    _iid_ = Guid('{90a60394-80fe-4211-97f8-a5de14dd95d2}')
    @winrt_commethod(6)
    def get_User(self) -> win32more.Windows.System.User: ...
    @winrt_commethod(7)
    def CreateContainer(self, name: WinRT_String) -> win32more.Windows.Gaming.XboxLive.Storage.GameSaveContainer: ...
    @winrt_commethod(8)
    def DeleteContainerAsync(self, name: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Gaming.XboxLive.Storage.GameSaveOperationResult]: ...
    @winrt_commethod(9)
    def CreateContainerInfoQuery(self) -> win32more.Windows.Gaming.XboxLive.Storage.GameSaveContainerInfoQuery: ...
    @winrt_commethod(10)
    def CreateContainerInfoQueryWithName(self, containerNamePrefix: WinRT_String) -> win32more.Windows.Gaming.XboxLive.Storage.GameSaveContainerInfoQuery: ...
    @winrt_commethod(11)
    def GetRemainingBytesInQuotaAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[Int64]: ...
    @winrt_commethod(12)
    def get_ContainersChangedSinceLastSync(self) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    ContainersChangedSinceLastSync = property(get_ContainersChangedSinceLastSync, None)
    User = property(get_User, None)
class IGameSaveProviderGetResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.XboxLive.Storage.IGameSaveProviderGetResult'
    _iid_ = Guid('{3ab90816-d393-4d65-ac16-41c3e67ab945}')
    @winrt_commethod(6)
    def get_Status(self) -> win32more.Windows.Gaming.XboxLive.Storage.GameSaveErrorStatus: ...
    @winrt_commethod(7)
    def get_Value(self) -> win32more.Windows.Gaming.XboxLive.Storage.GameSaveProvider: ...
    Status = property(get_Status, None)
    Value = property(get_Value, None)
class IGameSaveProviderStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.XboxLive.Storage.IGameSaveProviderStatics'
    _iid_ = Guid('{d01d3ed0-7b03-449d-8cbd-3402842a1048}')
    @winrt_commethod(6)
    def GetForUserAsync(self, user: win32more.Windows.System.User, serviceConfigId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Gaming.XboxLive.Storage.GameSaveProviderGetResult]: ...
    @winrt_commethod(7)
    def GetSyncOnDemandForUserAsync(self, user: win32more.Windows.System.User, serviceConfigId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Gaming.XboxLive.Storage.GameSaveProviderGetResult]: ...


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation.Metadata
import win32more.Windows.Win32.System.WinRT
class ApiInformation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Foundation.Metadata.ApiInformation'
    @winrt_classmethod
    def IsTypePresent(cls: win32more.Windows.Foundation.Metadata.IApiInformationStatics, typeName: WinRT_String) -> Boolean: ...
    @winrt_classmethod
    def IsMethodPresent(cls: win32more.Windows.Foundation.Metadata.IApiInformationStatics, typeName: WinRT_String, methodName: WinRT_String) -> Boolean: ...
    @winrt_classmethod
    def IsMethodPresentWithArity(cls: win32more.Windows.Foundation.Metadata.IApiInformationStatics, typeName: WinRT_String, methodName: WinRT_String, inputParameterCount: UInt32) -> Boolean: ...
    @winrt_classmethod
    def IsEventPresent(cls: win32more.Windows.Foundation.Metadata.IApiInformationStatics, typeName: WinRT_String, eventName: WinRT_String) -> Boolean: ...
    @winrt_classmethod
    def IsPropertyPresent(cls: win32more.Windows.Foundation.Metadata.IApiInformationStatics, typeName: WinRT_String, propertyName: WinRT_String) -> Boolean: ...
    @winrt_classmethod
    def IsReadOnlyPropertyPresent(cls: win32more.Windows.Foundation.Metadata.IApiInformationStatics, typeName: WinRT_String, propertyName: WinRT_String) -> Boolean: ...
    @winrt_classmethod
    def IsWriteablePropertyPresent(cls: win32more.Windows.Foundation.Metadata.IApiInformationStatics, typeName: WinRT_String, propertyName: WinRT_String) -> Boolean: ...
    @winrt_classmethod
    def IsEnumNamedValuePresent(cls: win32more.Windows.Foundation.Metadata.IApiInformationStatics, enumTypeName: WinRT_String, valueName: WinRT_String) -> Boolean: ...
    @winrt_classmethod
    def IsApiContractPresentByMajor(cls: win32more.Windows.Foundation.Metadata.IApiInformationStatics, contractName: WinRT_String, majorVersion: UInt16) -> Boolean: ...
    @winrt_classmethod
    def IsApiContractPresentByMajorAndMinor(cls: win32more.Windows.Foundation.Metadata.IApiInformationStatics, contractName: WinRT_String, majorVersion: UInt16, minorVersion: UInt16) -> Boolean: ...
class AttributeTargets(Enum, UInt32):
    All = 4294967295
    Delegate = 1
    Enum = 2
    Event = 4
    Field = 8
    Interface = 16
    Method = 64
    Parameter = 128
    Property = 256
    RuntimeClass = 512
    Struct = 1024
    InterfaceImpl = 2048
    ApiContract = 8192
class CompositionType(Enum, Int32):
    Protected = 1
    Public = 2
class DeprecationType(Enum, Int32):
    Deprecate = 0
    Remove = 1
class FeatureStage(Enum, Int32):
    AlwaysDisabled = 0
    DisabledByDefault = 1
    EnabledByDefault = 2
    AlwaysEnabled = 3
class GCPressureAmount(Enum, Int32):
    Low = 0
    Medium = 1
    High = 2
class IApiInformationStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Foundation.Metadata.IApiInformationStatics'
    _iid_ = Guid('{997439fe-f681-4a11-b416-c13a47e8ba36}')
    @winrt_commethod(6)
    def IsTypePresent(self, typeName: WinRT_String) -> Boolean: ...
    @winrt_commethod(7)
    def IsMethodPresent(self, typeName: WinRT_String, methodName: WinRT_String) -> Boolean: ...
    @winrt_commethod(8)
    def IsMethodPresentWithArity(self, typeName: WinRT_String, methodName: WinRT_String, inputParameterCount: UInt32) -> Boolean: ...
    @winrt_commethod(9)
    def IsEventPresent(self, typeName: WinRT_String, eventName: WinRT_String) -> Boolean: ...
    @winrt_commethod(10)
    def IsPropertyPresent(self, typeName: WinRT_String, propertyName: WinRT_String) -> Boolean: ...
    @winrt_commethod(11)
    def IsReadOnlyPropertyPresent(self, typeName: WinRT_String, propertyName: WinRT_String) -> Boolean: ...
    @winrt_commethod(12)
    def IsWriteablePropertyPresent(self, typeName: WinRT_String, propertyName: WinRT_String) -> Boolean: ...
    @winrt_commethod(13)
    def IsEnumNamedValuePresent(self, enumTypeName: WinRT_String, valueName: WinRT_String) -> Boolean: ...
    @winrt_commethod(14)
    def IsApiContractPresentByMajor(self, contractName: WinRT_String, majorVersion: UInt16) -> Boolean: ...
    @winrt_commethod(15)
    def IsApiContractPresentByMajorAndMinor(self, contractName: WinRT_String, majorVersion: UInt16, minorVersion: UInt16) -> Boolean: ...
class MarshalingType(Enum, Int32):
    None_ = 1
    Agile = 2
    Standard = 3
    InvalidMarshaling = 0
class Platform(Enum, Int32):
    Windows = 0
    WindowsPhone = 1
class ThreadingModel(Enum, Int32):
    STA = 1
    MTA = 2
    Both = 3
    InvalidThreading = 0


make_ready(__name__)
